xrayutilities package
=====================

Subpackages
-----------

.. toctree::

    xrayutilities.analysis
    xrayutilities.io
    xrayutilities.materials
    xrayutilities.math
    xrayutilities.simpack

Submodules
----------

xrayutilities.config module
---------------------------

.. automodule:: xrayutilities.config
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.exception module
------------------------------

.. automodule:: xrayutilities.exception
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.experiment module
-------------------------------

.. automodule:: xrayutilities.experiment
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.gridder module
----------------------------

.. automodule:: xrayutilities.gridder
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.gridder2d module
------------------------------

.. automodule:: xrayutilities.gridder2d
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.gridder3d module
------------------------------

.. automodule:: xrayutilities.gridder3d
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.mpl\_helper module
--------------------------------

.. automodule:: xrayutilities.mpl_helper
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.normalize module
------------------------------

.. automodule:: xrayutilities.normalize
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.q2ang\_fit module
-------------------------------

.. automodule:: xrayutilities.q2ang_fit
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.utilities module
------------------------------

.. automodule:: xrayutilities.utilities
    :members:
    :undoc-members:
    :show-inheritance:

xrayutilities.utilities\_noconf module
--------------------------------------

.. automodule:: xrayutilities.utilities_noconf
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: xrayutilities
    :members:
    :undoc-members:
    :show-inheritance:
